@@ -94,7 +94,7 @@ ChatWindow::ChatWindow(Account* account, ChatSession* s)
 
 
 	sendButton = new QPushButton(tr("Send"), this);
-	sendButton->setEnabled(false);
+	//sendButton->setEnabled(false);
 	connect(sendButton, SIGNAL(clicked(bool)), this, SLOT(send()));
 	connect(m_account, SIGNAL(onlineStatusChanged(OnlineStatus)), this, SLOT(sendButtonEnabledProcess()));
 
@@ -169,8 +169,14 @@ ChatWindow::ChatWindow(Account* account, ChatSession* s)
 
 		smsEditor = new SmsEditor(s->account(), s->contact());
 		connect(smsEditor, SIGNAL(sendPressed()), this, SLOT(sendSms()));
-
-		splitter->addWidget(smsEditor);
+		QWidget* bottomWidget = new QWidget();
+		QHBoxLayout* bottomWidgetLayout = new QHBoxLayout(bottomWidget);
+		bottomWidgetLayout->setContentsMargins(0, 0, 0, 0);
+		bottomWidgetLayout->setSpacing(0);
+		bottomWidgetLayout->addWidget(smsEditor);
+		bottomWidgetLayout->addWidget(sendButton);
+		bottomWidget->setLayout(bottomWidgetLayout);
+		splitter->addWidget(bottomWidget);
 	}
 
 	checkContactStatus(session->contact()->status());
@@ -726,7 +732,7 @@ void ChatWindow::sendButtonEnabledProcess()
 	    else
 		    sendButton->setEnabled(true);
 	}
-	else if (smsEditor && smsEditor->isVisible())
+	else if (smsEditor)
 		sendButton->setEnabled(true);
 
 
